==> bacula-doc_5.0.1.orig.tar.bz2: bacula-docs-5.0.1/home-page/es/pages/home.php <==
<? require_once("inc/header.php"); ?>
<table>
<tr>
   <td class="contentTopic">
      Bacula&reg; - The Open Source Network Backup Solution
   </td>
</tr>
<tr>
  <td class="content">
     <b>Bacula</b> is a set of Open Source, enterprise ready,
     computer programs that permit you (or the system
     administrator) to manage backup, recovery, and verification
     of computer data across a network of computers of different
     kinds.
     Bacula is relatively easy to use and efficient, while
     offering many advanced storage management features that make
     it easy to find and recover lost or damaged files.
     In technical terms, it is an <b>Open Source, enterprise
     ready, network based backup program</b>.
     <br>
     <br>
     According to Source Forge statistics (rank and downloads),
     Bacula is by far the most popular Enterprise grade Open
     Source program.
     <br>
     <br>

<table width="759" border="0" cellspacing="2" cellpadding="0">
   <tr>
    <td width="25"></td>
    <td><font size="5" color="#739ab9"> <strong>Bacula.org and Bacula Systems: 
          How to find what you need.</strong></font></td>
   </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
</table>

<p></p>
<table width="644" border="0" cellspacing="0" cellpadding="0" height="224">
 <tr height="215">
  <td align="center" valign="middle" width="331" height="215">
   <table width="237" border="0" cellspacing="0" cellpadding="0">
    <tr>
     <td>
      <table width="158" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
       <tr>
        <td valign="top">
         <table class="cellcolor" width="276" border="0" cellspacing="0" cellpadding="0" height="137">
          <tr height="137">
           <td width="5" height="137"></td>
           <td width="210" height="137">
            <h4>Bacula.org is the community home of the Bacula project, for developers and contributors. You can find the latest release of Bacula here, along with full documentation.</h4>
           </td>
          </tr>
         </table>
        </td>
       </tr>
      </table>
     </td>
    </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
    <tr height="68">
     <td height="68">
      <p>30 April 2009: <strong>Bacula 3.0.1</strong> has been released.</p>
      <p></p>
      <p>See: <a href="http://www.bacula.org/en/?page=news">News</a></p>
     </td>
    </tr>
   </table>
  </td>
  <td rowspan="2" width="25" height="229">
   <table class="cellcolor" width="3" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="320">
    <tr height="60">
     <td height="60"></td>
    </tr>
   </table>
  </td>
  <td align="center" valign="middle" width="210" height="215">
   <table width="288" border="0" cellspacing="0" cellpadding="0">
    <tr>
     <td>
      <table width="276" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
       <tr>
        <td valign="top">
         <table class="cellcolor" width="264" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
          <tr height="137">
           <td width="5" height="137"></td>
           <td width="271" height="137">
            <h4><a href="http://www.baculasystems.com">Bacula Systems</a> is the commercial support, services and 
                training organization for Enterprises using Bacula. The Bacula Systems 
                website is found at <a href="http://www.baculasystems.com">www.baculasystems.com</a></h4>
           </td>
          </tr>
         </table>
        </td>
       </tr>
      </table>
     </td>
    </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
    <tr height="68">
     <td height="68">
      <p>7 July 2009: <strong><a href="http://www.baculasystems.com/eng/Products/Enterprise-Edition">
                     Bacula Enterprise Edition 2.6</a></strong> has been released.</p>
      <p>10 June 2009: <strong>Foundation Training Course: <a href="http://www.baculasystems.com/eng/About-us/Recent-news/Foundation-Course-Dates-Announced">dates announced</a><p>
      <p>See: <a href="http://www.baculasystems.com/eng/About-us/Recent-news">Bacula Systems News</a>
<!--
, 
          or <a href="http://www.baculasystems.com/eng/Products/Enterprise-Edition">
          Bacula Enterprise Edition main page</a></p>     
-->
     </td>
    </tr>
   </table>
  </td>
 </tr>
 <tr align="center" height="14">
  <td width="331" height="14">
   <table class="cellcolor" width="209" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="3">
    <tr align="center" height="3">
     <td align="right" width="275" height="3"></td>
    </tr>
   </table>
  </td>
  <td width="210" height="14">
   <table class="cellcolor" width="209" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="3">
    <tr height="3">
     <td width="209" height="3"></td>
    </tr>
   </table>
  </td>
 </tr>
</table>
<p></p>


     Most of the <b>Bacula</b> source code is released under the
     <b>GPL</b> version 2 license.  If you wish additional
     details, please follow the License link to your left.<br>

     <br>The Documentation link takes you to a page where you
     can access all the available Bacula documentation (HTML,
     PDF, and TGZ) both for the officially released version 
     and for the current code under development in the Source
     Forge GIT. The development version of the manual typically has
     more documentation, but may also document new features that are
     not in the released version.  The <b>Developer's Guide</b>
     presents important information for users who want to
     contribute to the Bacula project.<br>  
        
     <br>Bacula is released on
     SourceForge at <a href="http://sourceforge.net/projects/bacula">
     http://sourceforge.net/projects/bacula </a> where you can
     download the software.<br> <br> You may also use
     the links on the left side of this page for more
     information.  In particular, Current Files link takes
     you to the currently available downloads, and the All
     Downloads link takes you to a list of all files ever
     released to SourceForge.
  </td>
</tr>
</table>

<? require_once("inc/footer.php"); ?>

==> bacula-doc_5.0.2.orig.tar.bz2: bacula-docs-5.0.2/home-page/es/pages/home.php <==
<? require_once("inc/header.php"); ?>
<table>
<tr>
   <td class="contentTopic">
      Bacula&reg; - The Open Source Network Backup Solution
   </td>
</tr>
<tr>
  <td class="content">
     <b>Bacula</b> is a set of Open Source, enterprise ready,
     computer programs that permit you (or the system
     administrator) to manage backup, recovery, and verification
     of computer data across a network of computers of different
     kinds.
     Bacula is relatively easy to use and efficient, while
     offering many advanced storage management features that make
     it easy to find and recover lost or damaged files.
     In technical terms, it is an <b>Open Source, enterprise
     ready, network based backup program</b>.
     <br>
     <br>
     According to Source Forge statistics (rank and downloads),
     Bacula is by far the most popular Enterprise grade Open
     Source program.
     <br>
     <br>

<table width="759" border="0" cellspacing="2" cellpadding="0">
   <tr>
    <td width="25"></td>
    <td><font size="5" color="#739ab9"> <strong>Bacula.org and Bacula Systems: 
          How to find what you need.</strong></font></td>
   </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
</table>

<p></p>
<table width="644" border="0" cellspacing="0" cellpadding="0" height="224">
 <tr height="215">
  <td align="center" valign="middle" width="331" height="215">
   <table width="237" border="0" cellspacing="0" cellpadding="0">
    <tr>
     <td>
      <table width="158" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
       <tr>
        <td valign="top">
         <table class="cellcolor" width="276" border="0" cellspacing="0" cellpadding="0" height="137">
          <tr height="137">
           <td width="5" height="137"></td>
           <td width="210" height="137">
            <h4>Bacula.org is the community home of the Bacula project, for developers and contributors. You can find the latest release of Bacula here, along with full documentation.</h4>
           </td>
          </tr>
         </table>
        </td>
       </tr>
      </table>
     </td>
    </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
    <tr height="68">
     <td height="68">
      <p>25 February 2010: <strong>Bacula 5.0.1</strong> has been released.</p>
      <p></p>
      <p>See: <a href="http://www.bacula.org/en/?page=news">News</a></p>
     </td>
    </tr>
   </table>
  </td>
  <td rowspan="2" width="25" height="229">
   <table class="cellcolor" width="3" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="320">
    <tr height="60">
     <td height="60"></td>
    </tr>
   </table>
  </td>
  <td align="center" valign="middle" width="210" height="215">
   <table width="288" border="0" cellspacing="0" cellpadding="0">
    <tr>
     <td>
      <table width="276" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
       <tr>
        <td valign="top">
         <table class="cellcolor" width="264" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
          <tr height="137">
           <td width="5" height="137"></td>
           <td width="271" height="137">
            <h4><a href="http://www.baculasystems.com">Bacula Systems</a> is the commercial support, services and 
                training organization for Enterprises using Bacula. The Bacula Systems 
                website is found at <a href="http://www.baculasystems.com">www.baculasystems.com</a></h4>
           </td>
          </tr>
         </table>
        </td>
       </tr>
      </table>
     </td>
    </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
    <tr height="68">
     <td height="68">
      <p>7 July 2009: <strong><a href="http://www.baculasystems.com/eng/Products/Enterprise-Edition">
                     Bacula Enterprise Edition 2.6</a></strong> has been released.</p>
      <p>10 June 2009: <strong>Foundation Training Course: <a href="http://www.baculasystems.com/eng/About-us/Recent-news/Foundation-Course-Dates-Announced">dates announced</a><p>
      <p>See: <a href="http://www.baculasystems.com/eng/About-us/Recent-news">Bacula Systems News</a>
<!--
, 
          or <a href="http://www.baculasystems.com/eng/Products/Enterprise-Edition">
          Bacula Enterprise Edition main page</a></p>     
-->
     </td>
    </tr>
   </table>
  </td>
 </tr>
 <tr align="center" height="14">
  <td width="331" height="14">
   <table class="cellcolor" width="209" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="3">
    <tr align="center" height="3">
     <td align="right" width="275" height="3"></td>
    </tr>
   </table>
  </td>
  <td width="210" height="14">
   <table class="cellcolor" width="209" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="3">
    <tr height="3">
     <td width="209" height="3"></td>
    </tr>
   </table>
  </td>
 </tr>
</table>
<p></p>


     Most of the <b>Bacula</b> source code is released under the
     <b>GPL</b> version 2 license.  If you wish additional
     details, please follow the License link to your left.<br>

     <br>The Documentation link takes you to a page where you
     can access all the available Bacula documentation (HTML,
     PDF, and TGZ) both for the officially released version 
     and for the current code under development in the Source
     Forge GIT. The development version of the manual typically has
     more documentation, but may also document new features that are
     not in the released version.  The <b>Developer's Guide</b>
     presents important information for users who want to
     contribute to the Bacula project.<br>  
        
     <br>Bacula is released on
     SourceForge at <a href="http://sourceforge.net/projects/bacula">
     http://sourceforge.net/projects/bacula </a> where you can
     download the software.<br> <br> You may also use
     the links on the left side of this page for more
     information.  In particular, Current Files link takes
     you to the currently available downloads, and the All
     Downloads link takes you to a list of all files ever
     released to SourceForge.
  </td>
</tr>
</table>

<? require_once("inc/footer.php"); ?>
